Description Usage Arguments Details Value See Also Examples
The import function can import data from delimited text files, EXCEL spreadsheets, and statistical packages such as SAS, SPSS, and Stata.
1 |
file |
datafile to import. If missing, the user is prompted to select a file interactively. |
... |
parameters passed to the import function. See details below. |
The import function is a wrapper for the
haven,
readxl,
and vroom
packages.
a data frame
read_sas, read_dta, read_spss, read_excel, vroom
1 2 3 4 5 6 7 8 9 10 11 12 13 14 | ## Not run:
#import comma delimited file
mydataframe <- import("mydata.csv")
# import SAS binary data file
mydataframe <- import("mydata.sas7bdat")
# import the second sheet of an EXCEL workbook
mydataframe <- import("mydata.xlsx", sheet = 2)
# prompt for a file to import
mydataframe <- import()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.